# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: search.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='search.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\006Search\210\001\001',
  serialized_pb=b'\n\x0csearch.proto\x12\x05proto\x1a,protoc-gen-swagger/options/annotations.proto\"V\n\rSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t:6\x92\x41\x33\n\x0f*\rSearchRequest2 \x12\x1e{\"query\": \"ukraine documents\"}\"\x8a\x01\n\x0eSearchResponse\x12#\n\x04hits\x18\x01 \x03(\x0b\x32\x15.proto.DocumentResult:S\x92\x41P\n\x10*\x0eSearchResponse2<\x12:{\"hits\": [{\"docID\": \"biden_investigation\", \"score\": 100}]}\".\n\x0e\x44ocumentResult\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x01\x42/\n\"com.strongsalt.strongdoc.sdk.protoB\x06Search\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_SEARCHREQUEST = _descriptor.Descriptor(
  name='SearchRequest',
  full_name='proto.SearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='proto.SearchRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A3\n\017*\rSearchRequest2 \022\036{\"query\": \"ukraine documents\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=155,
)


_SEARCHRESPONSE = _descriptor.Descriptor(
  name='SearchResponse',
  full_name='proto.SearchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hits', full_name='proto.SearchResponse.hits', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AP\n\020*\016SearchResponse2<\022:{\"hits\": [{\"docID\": \"biden_investigation\", \"score\": 100}]}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=296,
)


_DOCUMENTRESULT = _descriptor.Descriptor(
  name='DocumentResult',
  full_name='proto.DocumentResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DocumentResult.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='proto.DocumentResult.score', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=344,
)

_SEARCHRESPONSE.fields_by_name['hits'].message_type = _DOCUMENTRESULT
DESCRIPTOR.message_types_by_name['SearchRequest'] = _SEARCHREQUEST
DESCRIPTOR.message_types_by_name['SearchResponse'] = _SEARCHRESPONSE
DESCRIPTOR.message_types_by_name['DocumentResult'] = _DOCUMENTRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchRequest = _reflection.GeneratedProtocolMessageType('SearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREQUEST,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:proto.SearchRequest)
  })
_sym_db.RegisterMessage(SearchRequest)

SearchResponse = _reflection.GeneratedProtocolMessageType('SearchResponse', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHRESPONSE,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:proto.SearchResponse)
  })
_sym_db.RegisterMessage(SearchResponse)

DocumentResult = _reflection.GeneratedProtocolMessageType('DocumentResult', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTRESULT,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:proto.DocumentResult)
  })
_sym_db.RegisterMessage(DocumentResult)


DESCRIPTOR._options = None
_SEARCHREQUEST._options = None
_SEARCHRESPONSE._options = None
# @@protoc_insertion_point(module_scope)
