# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: accounts.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='accounts.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\007Account\210\001\001',
  serialized_pb=b'\n\x0e\x61\x63\x63ounts.proto\x12\x05proto\x1a,protoc-gen-swagger/options/annotations.proto\"\xb6\x04\n\x1bRegisterOrganizationRequest\x12\x0f\n\x07orgName\x18\x01 \x01(\t\x12\x0f\n\x07orgAddr\x18\x02 \x01(\t\x12\x10\n\x08userName\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\x14\n\x0csharableOrgs\x18\x06 \x03(\t\x12\x17\n\x0fmultiLevelShare\x18\x07 \x01(\x08\x12\x0e\n\x06source\x18\x08 \x01(\t\x12\x12\n\nsourceData\x18\t \x01(\t:\xee\x02\x92\x41\xea\x02\n\x1d*\x1bRegisterOrganizationRequest2\xc8\x02\x12\xc5\x02{\"orgName\": \"WhiteHouse\", \"orgAddr\": \"1600 Pennsylvania Ave NW, Washington, DC 20500\", \"userName\": \"Donald Trump\", \"password\": \"ukrainismyfriend\", \"email\": \"donald.trump@whitehouse.gov\", \"sharableOrgs\": [\"cnn\", \"fbi\", \"democrats\"], \"multiLevelShare\": true, \"source\": \"\", \"sourceData\": \"{\\\"registrationToken\\\": \\\"abcd1234\\\"}\"}\"\xa6\x01\n\x1cRegisterOrganizationResponse\x12\r\n\x05orgID\x18\x01 \x01(\t\x12\x0e\n\x06userID\x18\x02 \x01(\t:g\x92\x41\x64\n\x1e*\x1cRegisterOrganizationResponse2B\x12@{\"orgID\": \"WhiteHouse\", \"userID\": \"donald.trump@whitehouse.gov\"}\"\xeb\x01\n\x13RegisterUserRequest\x12\x10\n\x08userName\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\r\n\x05\x61\x64min\x18\x04 \x01(\x08:\x91\x01\x92\x41\x8d\x01\n\x15*\x13RegisterUserRequest2t\x12r{\"userName\": \"Mike Pence\", \"password\": \"donaldismyfriend\", \"email\": \"mike.pence@whitehouse.gov\", \"admin\": \"false\"}\"n\n\x14RegisterUserResponse\x12\x0e\n\x06userID\x18\x01 \x01(\t:F\x92\x41\x43\n\x16*\x14RegisterUserResponse2)\x12\'{\"userID\": \"mike.pence@whitehouse.gov\"}\"i\n\x11RemoveUserRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t:D\x92\x41\x41\n\x13*\x11RemoveUserRequest2*\x12({\"userID\": \"donal.trump@whitehouse.gov\"}\"N\n\x12RemoveUserResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x03:)\x92\x41&\n\x14*\x12RemoveUserResponse2\x0e\x12\x0c{\"count\": 1}\"k\n\x12PromoteUserRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t:E\x92\x41\x42\n\x14*\x12PromoteUserRequest2*\x12({\"userID\": \"donald.duck@whitehouse.gov\"}\"V\n\x13PromoteUserResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:.\x92\x41+\n\x14*\x12PromoteUserRequest2\x13\x12\x11{\"success\": true}\"j\n\x11\x44\x65moteUserRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t:E\x92\x41\x42\n\x13*\x11\x44\x65moteUserRequest2+\x12){\"userID\": \"donald.trump@whitehouse.gov\"}\"U\n\x12\x44\x65moteUserResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:.\x92\x41+\n\x14*\x12\x44\x65moteUserResponse2\x13\x12\x11{\"success\": true}\"\xbd\x01\n\x0cLoginRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\r\n\x05orgID\x18\x03 \x01(\t:|\x92\x41y\n\x0e*\x0cLoginRequest2g\x12\x65{\"userID\": \"donald.trump@whitehouse.gov\", \"password\": \"makeamericagreatagain\", \"orgID\": \"WhiteHouse\"}\"Q\n\rLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t:1\x92\x41.\n\x0f*\rLoginResponse2\x1b\x12\x19{\"token\": \"blahblahblah\"}\"%\n\rLogoutRequest:\x14\x92\x41\x11\n\x0f*\rLogoutRequest\"P\n\x0eLogoutResponse\x12\x0e\n\x06status\x18\x01 \x01(\t:.\x92\x41+\n\x10*\x0eLogoutResponse2\x17\x12\x15{\"status\": \"you OUT\"}\"+\n\x10ListUsersRequest:\x17\x92\x41\x14\n\x12*\x10ListUsersRequest\"\x89\x02\n\x11ListUsersResponse\x12\x32\n\x08orgUsers\x18\x01 \x03(\x0b\x32 .proto.ListUsersResponse.OrgUser\x1a<\n\x07OrgUser\x12\x10\n\x08userName\x18\x01 \x01(\t\x12\x0e\n\x06userID\x18\x02 \x01(\t\x12\x0f\n\x07isAdmin\x18\x03 \x01(\x08:\x81\x01\x92\x41~\n\x13*\x11ListUsersResponse2g\x12\x65{\"orgUsers\":[{\"userName\": \"Donald Trump\", \"userID\": \"donald.trump@whitehouse.gov\", \"isAdmin\": true}]}\"_\n\x19RemoveOrganizationRequest\x12\r\n\x05\x66orce\x18\x01 \x01(\x08:3\x92\x41\x30\n\x1b*\x19RemoveOrganizationRequest2\x11\x12\x0f{\"force\": true}\"e\n\x1aRemoveOrganizationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:6\x92\x41\x33\n\x1c*\x1aRemoveOrganizationResponse2\x13\x12\x11{\"success\": true}\"a\n\x15\x41\x64\x64SharableOrgRequest\x12\x10\n\x08newOrgID\x18\x01 \x01(\t:6\x92\x41\x33\n\x17*\x15\x41\x64\x64SharableOrgRequest2\x18\x12\x16{\"newOrgID\": \"string\"}\"]\n\x16\x41\x64\x64SharableOrgResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:2\x92\x41/\n\x18*\x16\x41\x64\x64SharableOrgResponse2\x13\x12\x11{\"success\": true}\"m\n\x18RemoveSharableOrgRequest\x12\x13\n\x0bremoveOrgID\x18\x01 \x01(\t:<\x92\x41\x39\n\x1a*\x18RemoveSharableOrgRequest2\x1b\x12\x19{\"removeOrgID\": \"string\"}\"c\n\x19RemoveSharableOrgResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:5\x92\x41\x32\n\x1b*\x19RemoveSharableOrgResponse2\x13\x12\x11{\"success\": true}\"e\n\x1bSetMultiLevelSharingRequest\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08:6\x92\x41\x33\n\x1d*\x1bSetMultiLevelSharingRequest2\x12\x12\x10{\"enable\": true}\"i\n\x1cSetMultiLevelSharingResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:8\x92\x41\x35\n\x1e*\x1cSetMultiLevelSharingResponse2\x13\x12\x11{\"success\": true}B0\n\"com.strongsalt.strongdoc.sdk.protoB\x07\x41\x63\x63ount\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_REGISTERORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='RegisterOrganizationRequest',
  full_name='proto.RegisterOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgName', full_name='proto.RegisterOrganizationRequest.orgName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orgAddr', full_name='proto.RegisterOrganizationRequest.orgAddr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userName', full_name='proto.RegisterOrganizationRequest.userName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='proto.RegisterOrganizationRequest.password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='proto.RegisterOrganizationRequest.email', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sharableOrgs', full_name='proto.RegisterOrganizationRequest.sharableOrgs', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multiLevelShare', full_name='proto.RegisterOrganizationRequest.multiLevelShare', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='proto.RegisterOrganizationRequest.source', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceData', full_name='proto.RegisterOrganizationRequest.sourceData', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\352\002\n\035*\033RegisterOrganizationRequest2\310\002\022\305\002{\"orgName\": \"WhiteHouse\", \"orgAddr\": \"1600 Pennsylvania Ave NW, Washington, DC 20500\", \"userName\": \"Donald Trump\", \"password\": \"ukrainismyfriend\", \"email\": \"donald.trump@whitehouse.gov\", \"sharableOrgs\": [\"cnn\", \"fbi\", \"democrats\"], \"multiLevelShare\": true, \"source\": \"\", \"sourceData\": \"{\\\"registrationToken\\\": \\\"abcd1234\\\"}\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=638,
)


_REGISTERORGANIZATIONRESPONSE = _descriptor.Descriptor(
  name='RegisterOrganizationResponse',
  full_name='proto.RegisterOrganizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgID', full_name='proto.RegisterOrganizationResponse.orgID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.RegisterOrganizationResponse.userID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222Ad\n\036*\034RegisterOrganizationResponse2B\022@{\"orgID\": \"WhiteHouse\", \"userID\": \"donald.trump@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=807,
)


_REGISTERUSERREQUEST = _descriptor.Descriptor(
  name='RegisterUserRequest',
  full_name='proto.RegisterUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userName', full_name='proto.RegisterUserRequest.userName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='proto.RegisterUserRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='proto.RegisterUserRequest.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='admin', full_name='proto.RegisterUserRequest.admin', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\215\001\n\025*\023RegisterUserRequest2t\022r{\"userName\": \"Mike Pence\", \"password\": \"donaldismyfriend\", \"email\": \"mike.pence@whitehouse.gov\", \"admin\": \"false\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=1045,
)


_REGISTERUSERRESPONSE = _descriptor.Descriptor(
  name='RegisterUserResponse',
  full_name='proto.RegisterUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.RegisterUserResponse.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AC\n\026*\024RegisterUserResponse2)\022\'{\"userID\": \"mike.pence@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1157,
)


_REMOVEUSERREQUEST = _descriptor.Descriptor(
  name='RemoveUserRequest',
  full_name='proto.RemoveUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.RemoveUserRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AA\n\023*\021RemoveUserRequest2*\022({\"userID\": \"donal.trump@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1159,
  serialized_end=1264,
)


_REMOVEUSERRESPONSE = _descriptor.Descriptor(
  name='RemoveUserResponse',
  full_name='proto.RemoveUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='proto.RemoveUserResponse.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A&\n\024*\022RemoveUserResponse2\016\022\014{\"count\": 1}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1344,
)


_PROMOTEUSERREQUEST = _descriptor.Descriptor(
  name='PromoteUserRequest',
  full_name='proto.PromoteUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.PromoteUserRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AB\n\024*\022PromoteUserRequest2*\022({\"userID\": \"donald.duck@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1453,
)


_PROMOTEUSERRESPONSE = _descriptor.Descriptor(
  name='PromoteUserResponse',
  full_name='proto.PromoteUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.PromoteUserResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A+\n\024*\022PromoteUserRequest2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1455,
  serialized_end=1541,
)


_DEMOTEUSERREQUEST = _descriptor.Descriptor(
  name='DemoteUserRequest',
  full_name='proto.DemoteUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.DemoteUserRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AB\n\023*\021DemoteUserRequest2+\022){\"userID\": \"donald.trump@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1543,
  serialized_end=1649,
)


_DEMOTEUSERRESPONSE = _descriptor.Descriptor(
  name='DemoteUserResponse',
  full_name='proto.DemoteUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.DemoteUserResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A+\n\024*\022DemoteUserResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1651,
  serialized_end=1736,
)


_LOGINREQUEST = _descriptor.Descriptor(
  name='LoginRequest',
  full_name='proto.LoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.LoginRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='proto.LoginRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orgID', full_name='proto.LoginRequest.orgID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222Ay\n\016*\014LoginRequest2g\022e{\"userID\": \"donald.trump@whitehouse.gov\", \"password\": \"makeamericagreatagain\", \"orgID\": \"WhiteHouse\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1739,
  serialized_end=1928,
)


_LOGINRESPONSE = _descriptor.Descriptor(
  name='LoginResponse',
  full_name='proto.LoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.LoginResponse.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A.\n\017*\rLoginResponse2\033\022\031{\"token\": \"blahblahblah\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1930,
  serialized_end=2011,
)


_LOGOUTREQUEST = _descriptor.Descriptor(
  name='LogoutRequest',
  full_name='proto.LogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\021\n\017*\rLogoutRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2013,
  serialized_end=2050,
)


_LOGOUTRESPONSE = _descriptor.Descriptor(
  name='LogoutResponse',
  full_name='proto.LogoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.LogoutResponse.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A+\n\020*\016LogoutResponse2\027\022\025{\"status\": \"you OUT\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2052,
  serialized_end=2132,
)


_LISTUSERSREQUEST = _descriptor.Descriptor(
  name='ListUsersRequest',
  full_name='proto.ListUsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\024\n\022*\020ListUsersRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2134,
  serialized_end=2177,
)


_LISTUSERSRESPONSE_ORGUSER = _descriptor.Descriptor(
  name='OrgUser',
  full_name='proto.ListUsersResponse.OrgUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userName', full_name='proto.ListUsersResponse.OrgUser.userName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.ListUsersResponse.OrgUser.userID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isAdmin', full_name='proto.ListUsersResponse.OrgUser.isAdmin', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2253,
  serialized_end=2313,
)

_LISTUSERSRESPONSE = _descriptor.Descriptor(
  name='ListUsersResponse',
  full_name='proto.ListUsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgUsers', full_name='proto.ListUsersResponse.orgUsers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTUSERSRESPONSE_ORGUSER, ],
  enum_types=[
  ],
  serialized_options=b'\222A~\n\023*\021ListUsersResponse2g\022e{\"orgUsers\":[{\"userName\": \"Donald Trump\", \"userID\": \"donald.trump@whitehouse.gov\", \"isAdmin\": true}]}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2180,
  serialized_end=2445,
)


_REMOVEORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='RemoveOrganizationRequest',
  full_name='proto.RemoveOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='force', full_name='proto.RemoveOrganizationRequest.force', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A0\n\033*\031RemoveOrganizationRequest2\021\022\017{\"force\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2447,
  serialized_end=2542,
)


_REMOVEORGANIZATIONRESPONSE = _descriptor.Descriptor(
  name='RemoveOrganizationResponse',
  full_name='proto.RemoveOrganizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.RemoveOrganizationResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A3\n\034*\032RemoveOrganizationResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2544,
  serialized_end=2645,
)


_ADDSHARABLEORGREQUEST = _descriptor.Descriptor(
  name='AddSharableOrgRequest',
  full_name='proto.AddSharableOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='newOrgID', full_name='proto.AddSharableOrgRequest.newOrgID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A3\n\027*\025AddSharableOrgRequest2\030\022\026{\"newOrgID\": \"string\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2647,
  serialized_end=2744,
)


_ADDSHARABLEORGRESPONSE = _descriptor.Descriptor(
  name='AddSharableOrgResponse',
  full_name='proto.AddSharableOrgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.AddSharableOrgResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A/\n\030*\026AddSharableOrgResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2746,
  serialized_end=2839,
)


_REMOVESHARABLEORGREQUEST = _descriptor.Descriptor(
  name='RemoveSharableOrgRequest',
  full_name='proto.RemoveSharableOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='removeOrgID', full_name='proto.RemoveSharableOrgRequest.removeOrgID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A9\n\032*\030RemoveSharableOrgRequest2\033\022\031{\"removeOrgID\": \"string\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2841,
  serialized_end=2950,
)


_REMOVESHARABLEORGRESPONSE = _descriptor.Descriptor(
  name='RemoveSharableOrgResponse',
  full_name='proto.RemoveSharableOrgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.RemoveSharableOrgResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A2\n\033*\031RemoveSharableOrgResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2952,
  serialized_end=3051,
)


_SETMULTILEVELSHARINGREQUEST = _descriptor.Descriptor(
  name='SetMultiLevelSharingRequest',
  full_name='proto.SetMultiLevelSharingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='proto.SetMultiLevelSharingRequest.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A3\n\035*\033SetMultiLevelSharingRequest2\022\022\020{\"enable\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3053,
  serialized_end=3154,
)


_SETMULTILEVELSHARINGRESPONSE = _descriptor.Descriptor(
  name='SetMultiLevelSharingResponse',
  full_name='proto.SetMultiLevelSharingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.SetMultiLevelSharingResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A5\n\036*\034SetMultiLevelSharingResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3156,
  serialized_end=3261,
)

_LISTUSERSRESPONSE_ORGUSER.containing_type = _LISTUSERSRESPONSE
_LISTUSERSRESPONSE.fields_by_name['orgUsers'].message_type = _LISTUSERSRESPONSE_ORGUSER
DESCRIPTOR.message_types_by_name['RegisterOrganizationRequest'] = _REGISTERORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['RegisterOrganizationResponse'] = _REGISTERORGANIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['RegisterUserRequest'] = _REGISTERUSERREQUEST
DESCRIPTOR.message_types_by_name['RegisterUserResponse'] = _REGISTERUSERRESPONSE
DESCRIPTOR.message_types_by_name['RemoveUserRequest'] = _REMOVEUSERREQUEST
DESCRIPTOR.message_types_by_name['RemoveUserResponse'] = _REMOVEUSERRESPONSE
DESCRIPTOR.message_types_by_name['PromoteUserRequest'] = _PROMOTEUSERREQUEST
DESCRIPTOR.message_types_by_name['PromoteUserResponse'] = _PROMOTEUSERRESPONSE
DESCRIPTOR.message_types_by_name['DemoteUserRequest'] = _DEMOTEUSERREQUEST
DESCRIPTOR.message_types_by_name['DemoteUserResponse'] = _DEMOTEUSERRESPONSE
DESCRIPTOR.message_types_by_name['LoginRequest'] = _LOGINREQUEST
DESCRIPTOR.message_types_by_name['LoginResponse'] = _LOGINRESPONSE
DESCRIPTOR.message_types_by_name['LogoutRequest'] = _LOGOUTREQUEST
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
DESCRIPTOR.message_types_by_name['ListUsersRequest'] = _LISTUSERSREQUEST
DESCRIPTOR.message_types_by_name['ListUsersResponse'] = _LISTUSERSRESPONSE
DESCRIPTOR.message_types_by_name['RemoveOrganizationRequest'] = _REMOVEORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['RemoveOrganizationResponse'] = _REMOVEORGANIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['AddSharableOrgRequest'] = _ADDSHARABLEORGREQUEST
DESCRIPTOR.message_types_by_name['AddSharableOrgResponse'] = _ADDSHARABLEORGRESPONSE
DESCRIPTOR.message_types_by_name['RemoveSharableOrgRequest'] = _REMOVESHARABLEORGREQUEST
DESCRIPTOR.message_types_by_name['RemoveSharableOrgResponse'] = _REMOVESHARABLEORGRESPONSE
DESCRIPTOR.message_types_by_name['SetMultiLevelSharingRequest'] = _SETMULTILEVELSHARINGREQUEST
DESCRIPTOR.message_types_by_name['SetMultiLevelSharingResponse'] = _SETMULTILEVELSHARINGRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RegisterOrganizationRequest = _reflection.GeneratedProtocolMessageType('RegisterOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERORGANIZATIONREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RegisterOrganizationRequest)
  })
_sym_db.RegisterMessage(RegisterOrganizationRequest)

RegisterOrganizationResponse = _reflection.GeneratedProtocolMessageType('RegisterOrganizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERORGANIZATIONRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RegisterOrganizationResponse)
  })
_sym_db.RegisterMessage(RegisterOrganizationResponse)

RegisterUserRequest = _reflection.GeneratedProtocolMessageType('RegisterUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERUSERREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RegisterUserRequest)
  })
_sym_db.RegisterMessage(RegisterUserRequest)

RegisterUserResponse = _reflection.GeneratedProtocolMessageType('RegisterUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERUSERRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RegisterUserResponse)
  })
_sym_db.RegisterMessage(RegisterUserResponse)

RemoveUserRequest = _reflection.GeneratedProtocolMessageType('RemoveUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEUSERREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveUserRequest)
  })
_sym_db.RegisterMessage(RemoveUserRequest)

RemoveUserResponse = _reflection.GeneratedProtocolMessageType('RemoveUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEUSERRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveUserResponse)
  })
_sym_db.RegisterMessage(RemoveUserResponse)

PromoteUserRequest = _reflection.GeneratedProtocolMessageType('PromoteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROMOTEUSERREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.PromoteUserRequest)
  })
_sym_db.RegisterMessage(PromoteUserRequest)

PromoteUserResponse = _reflection.GeneratedProtocolMessageType('PromoteUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROMOTEUSERRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.PromoteUserResponse)
  })
_sym_db.RegisterMessage(PromoteUserResponse)

DemoteUserRequest = _reflection.GeneratedProtocolMessageType('DemoteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEMOTEUSERREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.DemoteUserRequest)
  })
_sym_db.RegisterMessage(DemoteUserRequest)

DemoteUserResponse = _reflection.GeneratedProtocolMessageType('DemoteUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEMOTEUSERRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.DemoteUserResponse)
  })
_sym_db.RegisterMessage(DemoteUserResponse)

LoginRequest = _reflection.GeneratedProtocolMessageType('LoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.LoginRequest)
  })
_sym_db.RegisterMessage(LoginRequest)

LoginResponse = _reflection.GeneratedProtocolMessageType('LoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.LoginResponse)
  })
_sym_db.RegisterMessage(LoginResponse)

LogoutRequest = _reflection.GeneratedProtocolMessageType('LogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.LogoutRequest)
  })
_sym_db.RegisterMessage(LogoutRequest)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.LogoutResponse)
  })
_sym_db.RegisterMessage(LogoutResponse)

ListUsersRequest = _reflection.GeneratedProtocolMessageType('ListUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.ListUsersRequest)
  })
_sym_db.RegisterMessage(ListUsersRequest)

ListUsersResponse = _reflection.GeneratedProtocolMessageType('ListUsersResponse', (_message.Message,), {

  'OrgUser' : _reflection.GeneratedProtocolMessageType('OrgUser', (_message.Message,), {
    'DESCRIPTOR' : _LISTUSERSRESPONSE_ORGUSER,
    '__module__' : 'accounts_pb2'
    # @@protoc_insertion_point(class_scope:proto.ListUsersResponse.OrgUser)
    })
  ,
  'DESCRIPTOR' : _LISTUSERSRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.ListUsersResponse)
  })
_sym_db.RegisterMessage(ListUsersResponse)
_sym_db.RegisterMessage(ListUsersResponse.OrgUser)

RemoveOrganizationRequest = _reflection.GeneratedProtocolMessageType('RemoveOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEORGANIZATIONREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveOrganizationRequest)
  })
_sym_db.RegisterMessage(RemoveOrganizationRequest)

RemoveOrganizationResponse = _reflection.GeneratedProtocolMessageType('RemoveOrganizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEORGANIZATIONRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveOrganizationResponse)
  })
_sym_db.RegisterMessage(RemoveOrganizationResponse)

AddSharableOrgRequest = _reflection.GeneratedProtocolMessageType('AddSharableOrgRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDSHARABLEORGREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.AddSharableOrgRequest)
  })
_sym_db.RegisterMessage(AddSharableOrgRequest)

AddSharableOrgResponse = _reflection.GeneratedProtocolMessageType('AddSharableOrgResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDSHARABLEORGRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.AddSharableOrgResponse)
  })
_sym_db.RegisterMessage(AddSharableOrgResponse)

RemoveSharableOrgRequest = _reflection.GeneratedProtocolMessageType('RemoveSharableOrgRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESHARABLEORGREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveSharableOrgRequest)
  })
_sym_db.RegisterMessage(RemoveSharableOrgRequest)

RemoveSharableOrgResponse = _reflection.GeneratedProtocolMessageType('RemoveSharableOrgResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESHARABLEORGRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveSharableOrgResponse)
  })
_sym_db.RegisterMessage(RemoveSharableOrgResponse)

SetMultiLevelSharingRequest = _reflection.GeneratedProtocolMessageType('SetMultiLevelSharingRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMULTILEVELSHARINGREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.SetMultiLevelSharingRequest)
  })
_sym_db.RegisterMessage(SetMultiLevelSharingRequest)

SetMultiLevelSharingResponse = _reflection.GeneratedProtocolMessageType('SetMultiLevelSharingResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETMULTILEVELSHARINGRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.SetMultiLevelSharingResponse)
  })
_sym_db.RegisterMessage(SetMultiLevelSharingResponse)


DESCRIPTOR._options = None
_REGISTERORGANIZATIONREQUEST._options = None
_REGISTERORGANIZATIONRESPONSE._options = None
_REGISTERUSERREQUEST._options = None
_REGISTERUSERRESPONSE._options = None
_REMOVEUSERREQUEST._options = None
_REMOVEUSERRESPONSE._options = None
_PROMOTEUSERREQUEST._options = None
_PROMOTEUSERRESPONSE._options = None
_DEMOTEUSERREQUEST._options = None
_DEMOTEUSERRESPONSE._options = None
_LOGINREQUEST._options = None
_LOGINRESPONSE._options = None
_LOGOUTREQUEST._options = None
_LOGOUTRESPONSE._options = None
_LISTUSERSREQUEST._options = None
_LISTUSERSRESPONSE._options = None
_REMOVEORGANIZATIONREQUEST._options = None
_REMOVEORGANIZATIONRESPONSE._options = None
_ADDSHARABLEORGREQUEST._options = None
_ADDSHARABLEORGRESPONSE._options = None
_REMOVESHARABLEORGREQUEST._options = None
_REMOVESHARABLEORGRESPONSE._options = None
_SETMULTILEVELSHARINGREQUEST._options = None
_SETMULTILEVELSHARINGRESPONSE._options = None
# @@protoc_insertion_point(module_scope)
