# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: document.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='document.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\tDocuments\210\001\001',
  serialized_pb=b'\n\x0e\x64ocument.proto\x12\x05proto\x1a,protoc-gen-swagger/options/annotations.proto\"J\n\x12UploadDocStreamReq\x12\x11\n\x07\x64ocName\x18\x01 \x01(\tH\x00\x12\x13\n\tplaintext\x18\x02 \x01(\x0cH\x00\x42\x0c\n\nNameOrData\"3\n\x13UploadDocStreamResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\r\n\x05\x62ytes\x18\x02 \x01(\x03\"%\n\x14\x44ownloadDocStreamReq\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\"9\n\x15\x44ownloadDocStreamResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\x0c\"\x8c\x01\n\x0cUploadDocReq\x12\x0f\n\x07\x64ocName\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t:X\x92\x41U\n\x0e*\x0cUploadDocReq2C\x12\x41{\"docName\": \"bribeamount\", \"plaintext\": \"I paid 1M to Volodymyr\"}\"S\n\rUploadDocResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t:3\x92\x41\x30\n\x0f*\rUploadDocResp2\x1d\x12\x1b{\"docID\": \"bribeamount_ID\"}\"U\n\x0e\x44ownloadDocReq\x12\r\n\x05\x64ocID\x18\x01 \x01(\t:4\x92\x41\x31\n\x10*\x0e\x44ownloadDocReq2\x1d\x12\x1b{\"docID\": \"bribeamount_ID\"}\"\x90\x01\n\x0f\x44ownloadDocResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t:[\x92\x41X\n\x10*\x0e\x44ownloadDocReq2D\x12\x42{\"docID\": \"bribeamount_ID\", \"plaintext\": \"I paid 1M to Volodymyr\"}\"\x82\x01\n\x14ShareDocumentRequest\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x0e\n\x06userID\x18\x02 \x01(\t:K\x92\x41H\n\x16*\x14ShareDocumentRequest2.\x12,{\"docID\": \"bribeamount_ID\", \"userID\": \"FBI\"}\"[\n\x15ShareDocumentResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:1\x92\x41.\n\x17*\x15ShareDocumentResponse2\x13\x12\x11{\"success\": true}\"\x8b\x01\n\x16UnshareDocumentRequest\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x0e\n\x06userID\x18\x02 \x01(\t:R\x92\x41O\n\x18*\x16UnshareDocumentRequest23\x12\x31{\"docID\": \"bribeamount_ID\", \"userID\": \"Fox News\"}\"X\n\x17UnshareDocumentResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x03:.\x92\x41+\n\x19*\x17UnshareDocumentResponse2\x0e\x12\x0c{\"count\": 1}\"3\n\x14ListDocumentsRequest:\x1b\x92\x41\x18\n\x16*\x14ListDocumentsRequest\"\x84\x02\n\x15ListDocumentsResponse\x12\x38\n\tdocuments\x18\x01 \x03(\x0b\x32%.proto.ListDocumentsResponse.Document\x1a\x38\n\x08\x44ocument\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x0f\n\x07\x64ocName\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x04:w\x92\x41t\n\x17*\x15ListDocumentsResponse2Y\x12W{\"documents\": [{\"docID\": \"bribeamount_ID\", \"docName\": \"bribeamount.pdf\", \"size\": 561}]}\"c\n\x15RemoveDocumentRequest\x12\r\n\x05\x64ocID\x18\x01 \x01(\t:;\x92\x41\x38\n\x17*\x15RemoveDocumentRequest2\x1d\x12\x1b{\"docID\": \"bribeamount_ID\"}\"[\n\x16RemoveDocumentResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08:1\x92\x41.\n\x18*\x16RemoveDocumentResponse2\x12\x12\x10{\"status\": true}B2\n\"com.strongsalt.strongdoc.sdk.protoB\tDocuments\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_UPLOADDOCSTREAMREQ = _descriptor.Descriptor(
  name='UploadDocStreamReq',
  full_name='proto.UploadDocStreamReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.UploadDocStreamReq.docName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.UploadDocStreamReq.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='NameOrData', full_name='proto.UploadDocStreamReq.NameOrData',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=71,
  serialized_end=145,
)


_UPLOADDOCSTREAMRESP = _descriptor.Descriptor(
  name='UploadDocStreamResp',
  full_name='proto.UploadDocStreamResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.UploadDocStreamResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='proto.UploadDocStreamResp.bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=198,
)


_DOWNLOADDOCSTREAMREQ = _descriptor.Descriptor(
  name='DownloadDocStreamReq',
  full_name='proto.DownloadDocStreamReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DownloadDocStreamReq.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=237,
)


_DOWNLOADDOCSTREAMRESP = _descriptor.Descriptor(
  name='DownloadDocStreamResp',
  full_name='proto.DownloadDocStreamResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DownloadDocStreamResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.DownloadDocStreamResp.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=296,
)


_UPLOADDOCREQ = _descriptor.Descriptor(
  name='UploadDocReq',
  full_name='proto.UploadDocReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.UploadDocReq.docName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.UploadDocReq.plaintext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AU\n\016*\014UploadDocReq2C\022A{\"docName\": \"bribeamount\", \"plaintext\": \"I paid 1M to Volodymyr\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=439,
)


_UPLOADDOCRESP = _descriptor.Descriptor(
  name='UploadDocResp',
  full_name='proto.UploadDocResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.UploadDocResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A0\n\017*\rUploadDocResp2\035\022\033{\"docID\": \"bribeamount_ID\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=524,
)


_DOWNLOADDOCREQ = _descriptor.Descriptor(
  name='DownloadDocReq',
  full_name='proto.DownloadDocReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DownloadDocReq.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A1\n\020*\016DownloadDocReq2\035\022\033{\"docID\": \"bribeamount_ID\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=611,
)


_DOWNLOADDOCRESP = _descriptor.Descriptor(
  name='DownloadDocResp',
  full_name='proto.DownloadDocResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DownloadDocResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.DownloadDocResp.plaintext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AX\n\020*\016DownloadDocReq2D\022B{\"docID\": \"bribeamount_ID\", \"plaintext\": \"I paid 1M to Volodymyr\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=758,
)


_SHAREDOCUMENTREQUEST = _descriptor.Descriptor(
  name='ShareDocumentRequest',
  full_name='proto.ShareDocumentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.ShareDocumentRequest.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.ShareDocumentRequest.userID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AH\n\026*\024ShareDocumentRequest2.\022,{\"docID\": \"bribeamount_ID\", \"userID\": \"FBI\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=891,
)


_SHAREDOCUMENTRESPONSE = _descriptor.Descriptor(
  name='ShareDocumentResponse',
  full_name='proto.ShareDocumentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.ShareDocumentResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A.\n\027*\025ShareDocumentResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=984,
)


_UNSHAREDOCUMENTREQUEST = _descriptor.Descriptor(
  name='UnshareDocumentRequest',
  full_name='proto.UnshareDocumentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.UnshareDocumentRequest.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.UnshareDocumentRequest.userID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AO\n\030*\026UnshareDocumentRequest23\0221{\"docID\": \"bribeamount_ID\", \"userID\": \"Fox News\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1126,
)


_UNSHAREDOCUMENTRESPONSE = _descriptor.Descriptor(
  name='UnshareDocumentResponse',
  full_name='proto.UnshareDocumentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='proto.UnshareDocumentResponse.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A+\n\031*\027UnshareDocumentResponse2\016\022\014{\"count\": 1}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1216,
)


_LISTDOCUMENTSREQUEST = _descriptor.Descriptor(
  name='ListDocumentsRequest',
  full_name='proto.ListDocumentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\030\n\026*\024ListDocumentsRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1269,
)


_LISTDOCUMENTSRESPONSE_DOCUMENT = _descriptor.Descriptor(
  name='Document',
  full_name='proto.ListDocumentsResponse.Document',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.ListDocumentsResponse.Document.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.ListDocumentsResponse.Document.docName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='proto.ListDocumentsResponse.Document.size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1355,
  serialized_end=1411,
)

_LISTDOCUMENTSRESPONSE = _descriptor.Descriptor(
  name='ListDocumentsResponse',
  full_name='proto.ListDocumentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='documents', full_name='proto.ListDocumentsResponse.documents', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTDOCUMENTSRESPONSE_DOCUMENT, ],
  enum_types=[
  ],
  serialized_options=b'\222At\n\027*\025ListDocumentsResponse2Y\022W{\"documents\": [{\"docID\": \"bribeamount_ID\", \"docName\": \"bribeamount.pdf\", \"size\": 561}]}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1272,
  serialized_end=1532,
)


_REMOVEDOCUMENTREQUEST = _descriptor.Descriptor(
  name='RemoveDocumentRequest',
  full_name='proto.RemoveDocumentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.RemoveDocumentRequest.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A8\n\027*\025RemoveDocumentRequest2\035\022\033{\"docID\": \"bribeamount_ID\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1534,
  serialized_end=1633,
)


_REMOVEDOCUMENTRESPONSE = _descriptor.Descriptor(
  name='RemoveDocumentResponse',
  full_name='proto.RemoveDocumentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.RemoveDocumentResponse.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A.\n\030*\026RemoveDocumentResponse2\022\022\020{\"status\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1635,
  serialized_end=1726,
)

_UPLOADDOCSTREAMREQ.oneofs_by_name['NameOrData'].fields.append(
  _UPLOADDOCSTREAMREQ.fields_by_name['docName'])
_UPLOADDOCSTREAMREQ.fields_by_name['docName'].containing_oneof = _UPLOADDOCSTREAMREQ.oneofs_by_name['NameOrData']
_UPLOADDOCSTREAMREQ.oneofs_by_name['NameOrData'].fields.append(
  _UPLOADDOCSTREAMREQ.fields_by_name['plaintext'])
_UPLOADDOCSTREAMREQ.fields_by_name['plaintext'].containing_oneof = _UPLOADDOCSTREAMREQ.oneofs_by_name['NameOrData']
_LISTDOCUMENTSRESPONSE_DOCUMENT.containing_type = _LISTDOCUMENTSRESPONSE
_LISTDOCUMENTSRESPONSE.fields_by_name['documents'].message_type = _LISTDOCUMENTSRESPONSE_DOCUMENT
DESCRIPTOR.message_types_by_name['UploadDocStreamReq'] = _UPLOADDOCSTREAMREQ
DESCRIPTOR.message_types_by_name['UploadDocStreamResp'] = _UPLOADDOCSTREAMRESP
DESCRIPTOR.message_types_by_name['DownloadDocStreamReq'] = _DOWNLOADDOCSTREAMREQ
DESCRIPTOR.message_types_by_name['DownloadDocStreamResp'] = _DOWNLOADDOCSTREAMRESP
DESCRIPTOR.message_types_by_name['UploadDocReq'] = _UPLOADDOCREQ
DESCRIPTOR.message_types_by_name['UploadDocResp'] = _UPLOADDOCRESP
DESCRIPTOR.message_types_by_name['DownloadDocReq'] = _DOWNLOADDOCREQ
DESCRIPTOR.message_types_by_name['DownloadDocResp'] = _DOWNLOADDOCRESP
DESCRIPTOR.message_types_by_name['ShareDocumentRequest'] = _SHAREDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name['ShareDocumentResponse'] = _SHAREDOCUMENTRESPONSE
DESCRIPTOR.message_types_by_name['UnshareDocumentRequest'] = _UNSHAREDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name['UnshareDocumentResponse'] = _UNSHAREDOCUMENTRESPONSE
DESCRIPTOR.message_types_by_name['ListDocumentsRequest'] = _LISTDOCUMENTSREQUEST
DESCRIPTOR.message_types_by_name['ListDocumentsResponse'] = _LISTDOCUMENTSRESPONSE
DESCRIPTOR.message_types_by_name['RemoveDocumentRequest'] = _REMOVEDOCUMENTREQUEST
DESCRIPTOR.message_types_by_name['RemoveDocumentResponse'] = _REMOVEDOCUMENTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadDocStreamReq = _reflection.GeneratedProtocolMessageType('UploadDocStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDOCSTREAMREQ,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UploadDocStreamReq)
  })
_sym_db.RegisterMessage(UploadDocStreamReq)

UploadDocStreamResp = _reflection.GeneratedProtocolMessageType('UploadDocStreamResp', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDOCSTREAMRESP,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UploadDocStreamResp)
  })
_sym_db.RegisterMessage(UploadDocStreamResp)

DownloadDocStreamReq = _reflection.GeneratedProtocolMessageType('DownloadDocStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDOCSTREAMREQ,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.DownloadDocStreamReq)
  })
_sym_db.RegisterMessage(DownloadDocStreamReq)

DownloadDocStreamResp = _reflection.GeneratedProtocolMessageType('DownloadDocStreamResp', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDOCSTREAMRESP,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.DownloadDocStreamResp)
  })
_sym_db.RegisterMessage(DownloadDocStreamResp)

UploadDocReq = _reflection.GeneratedProtocolMessageType('UploadDocReq', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDOCREQ,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UploadDocReq)
  })
_sym_db.RegisterMessage(UploadDocReq)

UploadDocResp = _reflection.GeneratedProtocolMessageType('UploadDocResp', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADDOCRESP,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UploadDocResp)
  })
_sym_db.RegisterMessage(UploadDocResp)

DownloadDocReq = _reflection.GeneratedProtocolMessageType('DownloadDocReq', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDOCREQ,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.DownloadDocReq)
  })
_sym_db.RegisterMessage(DownloadDocReq)

DownloadDocResp = _reflection.GeneratedProtocolMessageType('DownloadDocResp', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDOCRESP,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.DownloadDocResp)
  })
_sym_db.RegisterMessage(DownloadDocResp)

ShareDocumentRequest = _reflection.GeneratedProtocolMessageType('ShareDocumentRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDOCUMENTREQUEST,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.ShareDocumentRequest)
  })
_sym_db.RegisterMessage(ShareDocumentRequest)

ShareDocumentResponse = _reflection.GeneratedProtocolMessageType('ShareDocumentResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHAREDOCUMENTRESPONSE,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.ShareDocumentResponse)
  })
_sym_db.RegisterMessage(ShareDocumentResponse)

UnshareDocumentRequest = _reflection.GeneratedProtocolMessageType('UnshareDocumentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNSHAREDOCUMENTREQUEST,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UnshareDocumentRequest)
  })
_sym_db.RegisterMessage(UnshareDocumentRequest)

UnshareDocumentResponse = _reflection.GeneratedProtocolMessageType('UnshareDocumentResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNSHAREDOCUMENTRESPONSE,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.UnshareDocumentResponse)
  })
_sym_db.RegisterMessage(UnshareDocumentResponse)

ListDocumentsRequest = _reflection.GeneratedProtocolMessageType('ListDocumentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDOCUMENTSREQUEST,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.ListDocumentsRequest)
  })
_sym_db.RegisterMessage(ListDocumentsRequest)

ListDocumentsResponse = _reflection.GeneratedProtocolMessageType('ListDocumentsResponse', (_message.Message,), {

  'Document' : _reflection.GeneratedProtocolMessageType('Document', (_message.Message,), {
    'DESCRIPTOR' : _LISTDOCUMENTSRESPONSE_DOCUMENT,
    '__module__' : 'document_pb2'
    # @@protoc_insertion_point(class_scope:proto.ListDocumentsResponse.Document)
    })
  ,
  'DESCRIPTOR' : _LISTDOCUMENTSRESPONSE,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.ListDocumentsResponse)
  })
_sym_db.RegisterMessage(ListDocumentsResponse)
_sym_db.RegisterMessage(ListDocumentsResponse.Document)

RemoveDocumentRequest = _reflection.GeneratedProtocolMessageType('RemoveDocumentRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDOCUMENTREQUEST,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveDocumentRequest)
  })
_sym_db.RegisterMessage(RemoveDocumentRequest)

RemoveDocumentResponse = _reflection.GeneratedProtocolMessageType('RemoveDocumentResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDOCUMENTRESPONSE,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveDocumentResponse)
  })
_sym_db.RegisterMessage(RemoveDocumentResponse)


DESCRIPTOR._options = None
_UPLOADDOCREQ._options = None
_UPLOADDOCRESP._options = None
_DOWNLOADDOCREQ._options = None
_DOWNLOADDOCRESP._options = None
_SHAREDOCUMENTREQUEST._options = None
_SHAREDOCUMENTRESPONSE._options = None
_UNSHAREDOCUMENTREQUEST._options = None
_UNSHAREDOCUMENTRESPONSE._options = None
_LISTDOCUMENTSREQUEST._options = None
_LISTDOCUMENTSRESPONSE._options = None
_REMOVEDOCUMENTREQUEST._options = None
_REMOVEDOCUMENTRESPONSE._options = None
# @@protoc_insertion_point(module_scope)
