# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: documentNoStore.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='documentNoStore.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\020DocumentsNoStore\210\001\001',
  serialized_pb=b'\n\x15\x64ocumentNoStore.proto\x12\x05proto\x1a,protoc-gen-swagger/options/annotations.proto\"K\n\x13\x45ncryptDocStreamReq\x12\x11\n\x07\x64ocName\x18\x01 \x01(\tH\x00\x12\x13\n\tplaintext\x18\x02 \x01(\x0cH\x00\x42\x0c\n\nNameOrData\"9\n\x14\x45ncryptDocStreamResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x12\n\nciphertext\x18\x02 \x01(\x0c\"H\n\x13\x44\x65\x63ryptDocStreamReq\x12\x0f\n\x05\x64ocID\x18\x01 \x01(\tH\x00\x12\x14\n\nciphertext\x18\x02 \x01(\x0cH\x00\x42\n\n\x08IdOrData\"8\n\x14\x44\x65\x63ryptDocStreamResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\x0c\"\x92\x01\n\rEncryptDocReq\x12\x0f\n\x07\x64ocName\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t:]\x92\x41Z\n\x0f*\rEncryptDocReq2G\x12\x45{\"docName\": \"bribeamount.pdf\", \"plaintext\": \"I paid 1M to Volodymyr\"}\"\x93\x01\n\x0e\x45ncryptDocResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x12\n\nciphertext\x18\x02 \x01(\t:^\x92\x41[\n\x10*\x0e\x45ncryptDocResp2G\x12\x45{\"docID\": \"bribeamount_ID.pdf\", \"ciphertext\": \"very encrypted stuff\"}\"\x91\x01\n\rDecryptDocReq\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x12\n\nciphertext\x18\x02 \x01(\t:]\x92\x41Z\n\x0f*\rDecryptDocReq2G\x12\x45{\"docID\": \"bribeamount_ID.pdf\", \"ciphertext\": \"very encrypted stuff\"}\"\x93\x01\n\x0e\x44\x65\x63ryptDocResp\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t:_\x92\x41\\\n\x10*\x0e\x44\x65\x63ryptDocResp2H\x12\x46{\"docID\": \"bribeamount_ID.pdf\", \"plaintext\": \"I paid 1M to Volodymyr\"}B9\n\"com.strongsalt.strongdoc.sdk.protoB\x10\x44ocumentsNoStore\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_ENCRYPTDOCSTREAMREQ = _descriptor.Descriptor(
  name='EncryptDocStreamReq',
  full_name='proto.EncryptDocStreamReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.EncryptDocStreamReq.docName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.EncryptDocStreamReq.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='NameOrData', full_name='proto.EncryptDocStreamReq.NameOrData',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=78,
  serialized_end=153,
)


_ENCRYPTDOCSTREAMRESP = _descriptor.Descriptor(
  name='EncryptDocStreamResp',
  full_name='proto.EncryptDocStreamResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.EncryptDocStreamResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='proto.EncryptDocStreamResp.ciphertext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=212,
)


_DECRYPTDOCSTREAMREQ = _descriptor.Descriptor(
  name='DecryptDocStreamReq',
  full_name='proto.DecryptDocStreamReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DecryptDocStreamReq.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='proto.DecryptDocStreamReq.ciphertext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='IdOrData', full_name='proto.DecryptDocStreamReq.IdOrData',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=214,
  serialized_end=286,
)


_DECRYPTDOCSTREAMRESP = _descriptor.Descriptor(
  name='DecryptDocStreamResp',
  full_name='proto.DecryptDocStreamResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DecryptDocStreamResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.DecryptDocStreamResp.plaintext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=344,
)


_ENCRYPTDOCREQ = _descriptor.Descriptor(
  name='EncryptDocReq',
  full_name='proto.EncryptDocReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docName', full_name='proto.EncryptDocReq.docName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.EncryptDocReq.plaintext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AZ\n\017*\rEncryptDocReq2G\022E{\"docName\": \"bribeamount.pdf\", \"plaintext\": \"I paid 1M to Volodymyr\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=493,
)


_ENCRYPTDOCRESP = _descriptor.Descriptor(
  name='EncryptDocResp',
  full_name='proto.EncryptDocResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.EncryptDocResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='proto.EncryptDocResp.ciphertext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A[\n\020*\016EncryptDocResp2G\022E{\"docID\": \"bribeamount_ID.pdf\", \"ciphertext\": \"very encrypted stuff\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=496,
  serialized_end=643,
)


_DECRYPTDOCREQ = _descriptor.Descriptor(
  name='DecryptDocReq',
  full_name='proto.DecryptDocReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DecryptDocReq.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='proto.DecryptDocReq.ciphertext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AZ\n\017*\rDecryptDocReq2G\022E{\"docID\": \"bribeamount_ID.pdf\", \"ciphertext\": \"very encrypted stuff\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=791,
)


_DECRYPTDOCRESP = _descriptor.Descriptor(
  name='DecryptDocResp',
  full_name='proto.DecryptDocResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DecryptDocResp.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plaintext', full_name='proto.DecryptDocResp.plaintext', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\\\n\020*\016DecryptDocResp2H\022F{\"docID\": \"bribeamount_ID.pdf\", \"plaintext\": \"I paid 1M to Volodymyr\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=941,
)

_ENCRYPTDOCSTREAMREQ.oneofs_by_name['NameOrData'].fields.append(
  _ENCRYPTDOCSTREAMREQ.fields_by_name['docName'])
_ENCRYPTDOCSTREAMREQ.fields_by_name['docName'].containing_oneof = _ENCRYPTDOCSTREAMREQ.oneofs_by_name['NameOrData']
_ENCRYPTDOCSTREAMREQ.oneofs_by_name['NameOrData'].fields.append(
  _ENCRYPTDOCSTREAMREQ.fields_by_name['plaintext'])
_ENCRYPTDOCSTREAMREQ.fields_by_name['plaintext'].containing_oneof = _ENCRYPTDOCSTREAMREQ.oneofs_by_name['NameOrData']
_DECRYPTDOCSTREAMREQ.oneofs_by_name['IdOrData'].fields.append(
  _DECRYPTDOCSTREAMREQ.fields_by_name['docID'])
_DECRYPTDOCSTREAMREQ.fields_by_name['docID'].containing_oneof = _DECRYPTDOCSTREAMREQ.oneofs_by_name['IdOrData']
_DECRYPTDOCSTREAMREQ.oneofs_by_name['IdOrData'].fields.append(
  _DECRYPTDOCSTREAMREQ.fields_by_name['ciphertext'])
_DECRYPTDOCSTREAMREQ.fields_by_name['ciphertext'].containing_oneof = _DECRYPTDOCSTREAMREQ.oneofs_by_name['IdOrData']
DESCRIPTOR.message_types_by_name['EncryptDocStreamReq'] = _ENCRYPTDOCSTREAMREQ
DESCRIPTOR.message_types_by_name['EncryptDocStreamResp'] = _ENCRYPTDOCSTREAMRESP
DESCRIPTOR.message_types_by_name['DecryptDocStreamReq'] = _DECRYPTDOCSTREAMREQ
DESCRIPTOR.message_types_by_name['DecryptDocStreamResp'] = _DECRYPTDOCSTREAMRESP
DESCRIPTOR.message_types_by_name['EncryptDocReq'] = _ENCRYPTDOCREQ
DESCRIPTOR.message_types_by_name['EncryptDocResp'] = _ENCRYPTDOCRESP
DESCRIPTOR.message_types_by_name['DecryptDocReq'] = _DECRYPTDOCREQ
DESCRIPTOR.message_types_by_name['DecryptDocResp'] = _DECRYPTDOCRESP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EncryptDocStreamReq = _reflection.GeneratedProtocolMessageType('EncryptDocStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTDOCSTREAMREQ,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.EncryptDocStreamReq)
  })
_sym_db.RegisterMessage(EncryptDocStreamReq)

EncryptDocStreamResp = _reflection.GeneratedProtocolMessageType('EncryptDocStreamResp', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTDOCSTREAMRESP,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.EncryptDocStreamResp)
  })
_sym_db.RegisterMessage(EncryptDocStreamResp)

DecryptDocStreamReq = _reflection.GeneratedProtocolMessageType('DecryptDocStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _DECRYPTDOCSTREAMREQ,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.DecryptDocStreamReq)
  })
_sym_db.RegisterMessage(DecryptDocStreamReq)

DecryptDocStreamResp = _reflection.GeneratedProtocolMessageType('DecryptDocStreamResp', (_message.Message,), {
  'DESCRIPTOR' : _DECRYPTDOCSTREAMRESP,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.DecryptDocStreamResp)
  })
_sym_db.RegisterMessage(DecryptDocStreamResp)

EncryptDocReq = _reflection.GeneratedProtocolMessageType('EncryptDocReq', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTDOCREQ,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.EncryptDocReq)
  })
_sym_db.RegisterMessage(EncryptDocReq)

EncryptDocResp = _reflection.GeneratedProtocolMessageType('EncryptDocResp', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTDOCRESP,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.EncryptDocResp)
  })
_sym_db.RegisterMessage(EncryptDocResp)

DecryptDocReq = _reflection.GeneratedProtocolMessageType('DecryptDocReq', (_message.Message,), {
  'DESCRIPTOR' : _DECRYPTDOCREQ,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.DecryptDocReq)
  })
_sym_db.RegisterMessage(DecryptDocReq)

DecryptDocResp = _reflection.GeneratedProtocolMessageType('DecryptDocResp', (_message.Message,), {
  'DESCRIPTOR' : _DECRYPTDOCRESP,
  '__module__' : 'documentNoStore_pb2'
  # @@protoc_insertion_point(class_scope:proto.DecryptDocResp)
  })
_sym_db.RegisterMessage(DecryptDocResp)


DESCRIPTOR._options = None
_ENCRYPTDOCREQ._options = None
_ENCRYPTDOCRESP._options = None
_DECRYPTDOCREQ._options = None
_DECRYPTDOCRESP._options = None
# @@protoc_insertion_point(module_scope)
